@@ -305,90 +305,6 @@ var _ = Describe("[rfe_id:4784][crit:high] Importer respects node placement", fu
 	})
 })
 
-var _ = Describe("Importer CDI config manipulation tests", func() {
-	f := framework.NewFramework(namespacePrefix)
-
-	var (
-		config         *cdiv1.CDIConfig
-		origSpec       *cdiv1.CDIConfigSpec
-		err            error
-		tinyCoreIsoURL = func() string { return fmt.Sprintf(utils.TinyCoreIsoURL, f.CdiInstallNs) }
-	)
-
-	BeforeEach(func() {
-		config, err = f.CdiClient.CdiV1beta1().CDIConfigs().Get(context.TODO(), common.ConfigName, metav1.GetOptions{})
-		Expect(err).ToNot(HaveOccurred())
-
-		origSpec = config.Spec.DeepCopy()
-	})
-
-	AfterEach(func() {
-		By("Restoring CDIConfig to original state")
-		err := utils.UpdateCDIConfig(f.CrClient, func(config *cdiv1.CDIConfigSpec) {
-			origSpec.DeepCopyInto(config)
-		})
-
-		Eventually(func() bool {
-			config, err = f.CdiClient.CdiV1beta1().CDIConfigs().Get(context.TODO(), common.ConfigName, metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			return reflect.DeepEqual(config.Spec, *origSpec)
-		}, 30*time.Second, time.Second).Should(BeTrue())
-	})
-
-	dvWithPvcSpec := func() *cdiv1.DataVolume {
-		return utils.NewDataVolumeWithHTTPImport("too-large-import", "50Mi", tinyCoreIsoURL())
-	}
-	dvWithStorageSpec := func() *cdiv1.DataVolume {
-		return utils.NewDataVolumeWithHTTPImportAndStorageSpec("too-large-import", "50Mi", tinyCoreIsoURL())
-	}
-	// value of .80 means 80% of filesystem is reserved for metadata,
-	// given 100Mi PVC, 80Mi is reserved, 20Mi available for image, we test using 50Mi PVC and around 20Mi image
-	highFsOverhead := "0.80"
-
-	DescribeTable("Filesystem overhead is honored with a RAW file", func(dvFunc func() *cdiv1.DataVolume, expectedSuccess bool, globalOverhead, scOverhead string) {
-		tests.SetFilesystemOverhead(f, globalOverhead, scOverhead)
-
-		dv := dvFunc()
-		By(dv.Name)
-		dv, err = utils.CreateDataVolumeFromDefinition(f.CdiClient, f.Namespace.Name, dv)
-		Expect(err).ToNot(HaveOccurred())
-
-		pvc, err := utils.WaitForPVC(f.K8sClient, dv.Namespace, dv.Name)
-		Expect(err).ToNot(HaveOccurred())
-		f.ForceBindIfWaitForFirstConsumer(pvc)
-
-		importer, err := utils.FindPodByPrefix(f.K8sClient, f.Namespace.Name, common.ImporterPodName, common.CDILabelSelector)
-		Expect(err).NotTo(HaveOccurred(), fmt.Sprintf("Unable to get importer pod"))
-
-		if expectedSuccess {
-			By("Waiting for import to be completed")
-			err = utils.WaitForDataVolumePhase(f.CdiClient, f.Namespace.Name, cdiv1.Succeeded, dv.Name)
-			Expect(err).ToNot(HaveOccurred(), "Datavolume not in phase succeeded in time")
-		} else {
-			By(fmt.Sprintf("logs for pod -n %s %s", importer.Name, importer.Namespace))
-			By("Verify size error in logs")
-			Eventually(func() bool {
-				log, _ := tests.RunKubectlCommand(f, "logs", importer.Name, "-n", importer.Namespace)
-				if strings.Contains(log, "is larger than available size") {
-					return true
-				}
-				if strings.Contains(log, "no space left on device") {
-					return true
-				}
-				By("Failed to find error messages about a too large image in log:")
-				By(log)
-				return false
-			}, controllerSkipPVCCompleteTimeout, assertionPollInterval).Should(BeTrue())
-		}
-	},
-		Entry("Succeed with low global overhead", dvWithPvcSpec, true, "0.1", ""),
-		Entry("[posneg:negative] Fail with high global overhead", dvWithPvcSpec, false, highFsOverhead, ""),
-		Entry("Succeed with high global overhead when using spec.storage", dvWithStorageSpec, true, highFsOverhead, ""),
-		Entry("Succeed with low per-storageclass overhead (despite high global overhead)", dvWithPvcSpec, true, highFsOverhead, "0.1"),
-		Entry("[posneg:negative] Fail with high per-storageclass overhead (despite low global overhead)", dvWithPvcSpec, false, "0.1", highFsOverhead),
-	)
-})
-
 var _ = Describe("[rfe_id:1118][crit:high][vendor:cnv-qe@redhat.com][level:component]Importer Test Suite-prometheus", func() {
 	var prometheusURL string
 	var portForwardCmd *exec.Cmd
